<?php $TRANSLATIONS = array(
"Pictures" => "Images",
"Shared by" => "Partager par",
"Share" => "Partager",
"The \"Image Viewer\" application also need to be enabled to use this application." => "L'application \"Visualiseur d'Image\" nécessite d'être autorisée à utiliser cette application."
);
